@@ -352,9 +352,9 @@ _tp_account_manager_update_most_available_presence (TpAccountManager *manager)
 
   if (account == NULL)
     {
-      priv->most_available_presence = presence;
-      priv->most_available_status = NULL;
-      priv->most_available_status_message = NULL;
+      priv->most_available_presence = TP_CONNECTION_PRESENCE_TYPE_OFFLINE;
+      priv->most_available_status = g_strdup ("offline");
+      priv->most_available_status_message = g_strdup ("");
       return;
     }
 
@@ -371,6 +371,8 @@ _tp_account_manager_check_core_ready (TpAccountManager *manager)
 {
   TpAccountManagerPrivate *priv = manager->priv;
 
+  DEBUG ("manager has %d accounts left to prepare",
+    priv->n_preparing_accounts);
   if (tp_proxy_is_prepared (manager, TP_ACCOUNT_MANAGER_FEATURE_CORE))
     return;
 
@@ -416,6 +418,9 @@ account_prepared_cb (GObject *object,
       insert_account (self, account);
     }
 
+  DEBUG ("Account %s was prepared",
+      tp_proxy_get_object_path (object));
+
 OUT:
   self->priv->n_preparing_accounts--;
   _tp_account_manager_check_core_ready (self);
@@ -1275,7 +1280,7 @@ tp_account_manager_create_account_async (TpAccountManager *manager,
  * object, with the %TP_ACCOUNT_FEATURE_CORE feature ready on it.
  *
  * The caller must keep a ref to the returned object using g_object_ref() if
- * it is to be kept.
+ * it is to be kept beyond the lifetime of @result.
  *
  * Returns: (transfer none): a new #TpAccount which was just created on
  *  success, otherwise %NULL
@@ -1340,6 +1345,7 @@ tp_account_manager_is_prepared (TpAccountManager *manager,
  * tp_proxy_prepare_async() with the same arguments.
  *
  * Since: 0.9.0
+ * Deprecated: since 0.15.6, use tp_proxy_prepare_async() instead.
  */
 void
 tp_account_manager_prepare_async (TpAccountManager *manager,
@@ -1361,6 +1367,7 @@ tp_account_manager_prepare_async (TpAccountManager *manager,
  * Returns: %TRUE if the preparation was successful, otherwise %FALSE
  *
  * Since: 0.9.0
+ * Deprecated: since 0.15.6, use tp_proxy_prepare_finish() instead.
  */
 gboolean
 tp_account_manager_prepare_finish (TpAccountManager *manager,
