@@ -119,6 +119,15 @@ safe_g_object_unref (gpointer data)
   g_object_unref (data);
 }
 
+static gpointer
+safe_g_object_ref (gpointer data)
+{
+  if (data == NULL)
+    return NULL;
+
+  return g_object_ref (data);
+}
+
 static GHashTable *
 dup_owners_table (TpChannel *self,
     GHashTable *source,
@@ -223,13 +232,13 @@ _tp_channel_contacts_group_init (TpChannel *self,
     }
 }
 
-typedef struct
+struct _ContactsQueueItem
 {
   GSimpleAsyncResult *result;
   GPtrArray *contacts;
   GPtrArray *ids;
   GArray *handles;
-} ContactsQueueItem;
+};
 
 static ContactsQueueItem *
 contacts_queue_item_new (GPtrArray *contacts,
@@ -264,9 +273,7 @@ static void
 contacts_queue_head_ready (TpChannel *self,
     const GError *error)
 {
-  ContactsQueueItem *item;
-
-  item = g_queue_pop_head (self->priv->contacts_queue);
+  ContactsQueueItem *item = self->priv->current_item;
 
   if (error != NULL)
     {
@@ -275,6 +282,7 @@ contacts_queue_head_ready (TpChannel *self,
     }
   g_simple_async_result_complete (item->result);
 
+  self->priv->current_item = NULL;
   process_contacts_queue (self);
 
   contacts_queue_item_free (item);
@@ -357,8 +365,7 @@ process_contacts_queue (TpChannel *self)
   GArray *features;
   const GError *error = NULL;
 
-  item = g_queue_peek_head (self->priv->contacts_queue);
-  if (item == NULL)
+  if (self->priv->current_item != NULL)
     return;
 
   /* self can't die while there are queued items because item->result keeps a
@@ -378,6 +385,11 @@ process_contacts_queue (TpChannel *self)
       return;
     }
 
+  item = g_queue_pop_head (self->priv->contacts_queue);
+  if (item == NULL)
+    return;
+  self->priv->current_item = item;
+
   features = tp_simple_client_factory_dup_contact_features (
       tp_proxy_get_factory (self->priv->connection), self->priv->connection);
 
@@ -441,10 +453,7 @@ contacts_queue_item (TpChannel *self,
   g_simple_async_result_set_op_res_gpointer (item->result, item, NULL);
 
   g_queue_push_tail (self->priv->contacts_queue, item);
-
-  /* If this is the only item in the queue, we can process it right away */
-  if (self->priv->contacts_queue->length == 1)
-    process_contacts_queue (self);
+  process_contacts_queue (self);
 }
 
 void
@@ -712,7 +721,7 @@ handle_owners_changed_prepared_cb (GObject *object,
     }
 
   tp_g_hash_table_update (self->priv->group_contact_owners, data->added, NULL,
-      g_object_ref);
+      safe_g_object_ref);
 
   handle_owners_changed_data_free (data);
 }
@@ -1093,7 +1102,12 @@ append_contacts (GPtrArray *contacts,
 
   g_hash_table_iter_init (&iter, table);
   while (g_hash_table_iter_next (&iter, NULL, &value))
-    g_ptr_array_add (contacts, value);
+    {
+      if (value == NULL)
+        continue;
+
+      g_ptr_array_add (contacts, value);
+    }
 }
 
 void
