@@ -99,7 +99,6 @@ struct _TpSimplePasswordManagerPrivate
   guint status_changed_id;
 
   TpBasePasswordChannel *channel;
-  GAsyncResult *result;
 
   gboolean dispose_has_run;
 };
@@ -305,6 +304,12 @@ tp_simple_password_manager_channel_closed_cb (GObject *chan,
   tp_clear_object (&manager->priv->channel);
 }
 
+static void
+free_gstring (gpointer p)
+{
+  g_string_free (p, TRUE);
+}
+
 static void
 tp_simple_password_manager_channel_finished_cb (
     TpBasePasswordChannel *channel,
@@ -326,7 +331,7 @@ tp_simple_password_manager_channel_finished_cb (
   else
     {
       g_simple_async_result_set_op_res_gpointer (
-          result, (gpointer) str, NULL);
+          result, g_boxed_copy (G_TYPE_GSTRING, str), free_gstring);
     }
 
   g_simple_async_result_complete (result);
@@ -344,16 +349,14 @@ tp_simple_password_manager_prompt_common_async (
   g_return_if_fail (channel != NULL);
   g_return_if_fail (TP_IS_SIMPLE_PASSWORD_MANAGER (self));
   g_return_if_fail (priv->channel == NULL);
-  g_return_if_fail (priv->result == NULL);
 
   priv->channel = g_object_ref (channel);
-  priv->result = g_object_ref (result);
 
   tp_g_signal_connect_object (priv->channel, "closed",
       G_CALLBACK (tp_simple_password_manager_channel_closed_cb), self, 0);
   tp_g_signal_connect_object (priv->channel, "finished",
       G_CALLBACK (tp_simple_password_manager_channel_finished_cb),
-      priv->result, 0);
+      g_object_ref (result), 0);
 
   tp_base_channel_register ((TpBaseChannel *) priv->channel);
 
