@@ -250,6 +250,9 @@ test_succeeded (Test *test,
   g_signal_connect (test->cr, "succeeded-with-channel",
       G_CALLBACK (succeeded_with_channel_cb), test);
 
+  /* sync up both sockets to ensure that the match rules are in place */
+  tp_tests_proxy_run_until_dbus_queue_processed (test->cr);
+
   props = g_hash_table_new (NULL, NULL);
 
   tp_svc_channel_request_emit_succeeded_with_channel (test->cr_service,
@@ -288,6 +291,9 @@ test_failed (Test *test,
   g_signal_connect_swapped (test->cr, "succeeded", G_CALLBACK (succeeded_cb),
       test);
 
+  /* sync up both sockets to ensure that the match rules are in place */
+  tp_tests_proxy_run_until_dbus_queue_processed (test->cr);
+
   tp_svc_channel_request_emit_failed (test->cr_service,
       TP_ERROR_STR_NOT_YOURS, "lalala");
 
@@ -332,16 +338,24 @@ test_immutable_properties (Test *test,
   g_hash_table_unref (props);
 }
 
+#define ACCOUNT_PATH TP_ACCOUNT_OBJECT_PATH_BASE "a/b/c"
+
 static void
-test_hints (Test *test,
+test_properties (Test *test,
     gconstpointer data G_GNUC_UNUSED)
 {
   gboolean ok;
   GHashTable *props, *hints;
+  TpAccount *account;
+  gint64 user_action_time;
+  const gchar *handler;
 
   hints = tp_asv_new ("test", G_TYPE_STRING, "hi", NULL);
 
   props = tp_asv_new (
+      TP_PROP_CHANNEL_REQUEST_ACCOUNT, DBUS_TYPE_G_OBJECT_PATH, ACCOUNT_PATH,
+      TP_PROP_CHANNEL_REQUEST_USER_ACTION_TIME, G_TYPE_INT64, (gint64) 12345,
+      TP_PROP_CHANNEL_REQUEST_PREFERRED_HANDLER, G_TYPE_STRING, "Badger",
       TP_PROP_CHANNEL_REQUEST_HINTS, TP_HASH_TYPE_STRING_VARIANT_MAP, hints,
       NULL);
 
@@ -355,6 +369,31 @@ test_hints (Test *test,
   g_hash_table_unref (props);
   g_hash_table_unref (hints);
 
+  /* Account */
+  account = tp_channel_request_get_account (test->cr);
+  g_assert (TP_IS_ACCOUNT (account));
+  g_assert_cmpstr (tp_proxy_get_object_path (account), ==, ACCOUNT_PATH);
+
+  g_object_get (test->cr, "account", &account, NULL);
+  g_assert (TP_IS_ACCOUNT (account));
+  g_assert_cmpstr (tp_proxy_get_object_path (account), ==, ACCOUNT_PATH);
+  g_object_unref (account);
+
+  /* UserActionTime */
+  user_action_time = tp_channel_request_get_user_action_time (test->cr);
+  g_assert_cmpint (user_action_time, ==, 12345);
+
+  g_object_get (test->cr, "user-action-time", &user_action_time, NULL);
+  g_assert_cmpint (user_action_time, ==, 12345);
+
+  /* PreferredHandler */
+  handler = tp_channel_request_get_preferred_handler (test->cr);
+  g_assert_cmpstr (handler, ==, "Badger");
+
+  g_object_get (test->cr, "preferred-handler", &handler, NULL);
+  g_assert_cmpstr (handler, ==, "Badger");
+
+  /* Hints */
   hints = (GHashTable *) tp_channel_request_get_hints (test->cr);
   g_assert_cmpstr (tp_asv_get_string (hints, "test"), ==, "hi");
 
@@ -368,8 +407,7 @@ int
 main (int argc,
       char **argv)
 {
-  tp_tests_abort_after (10);
-  g_test_init (&argc, &argv, NULL);
+  tp_tests_init (&argc, &argv);
   g_test_bug_base ("http://bugs.freedesktop.org/show_bug.cgi?id=");
 
   g_test_add ("/cr/new", Test, NULL, setup, test_new, teardown);
@@ -378,7 +416,7 @@ main (int argc,
   g_test_add ("/cr/failed", Test, NULL, setup, test_failed, teardown);
   g_test_add ("/cr/immutable-properties", Test, NULL, setup,
       test_immutable_properties, teardown);
-  g_test_add ("/cr/hints", Test, NULL, setup, test_hints, teardown);
+  g_test_add ("/cr/properties", Test, NULL, setup, test_properties, teardown);
 
   return g_test_run ();
 }
