@@ -373,16 +373,6 @@ upgrade_cb (TpConnection *connection,
     }
 }
 
-/* Just put a country in locations for easier comparaisons.
- * FIXME: Ideally we should have a MYASSERT_SAME_ASV */
-#define ASSERT_SAME_LOCATION(left, right)\
-  G_STMT_START {\
-    g_assert_cmpuint (g_hash_table_size (left), ==, \
-        g_hash_table_size (right));\
-    g_assert_cmpstr (g_hash_table_lookup (left, "country"), ==,\
-        g_hash_table_lookup (right, "country"));\
-  } G_STMT_END
-
 static void
 test_upgrade (Fixture *f,
     gconstpointer unused G_GNUC_UNUSED)
@@ -401,19 +391,11 @@ test_upgrade (Fixture *f,
       TP_TESTS_CONTACTS_CONNECTION_STATUS_AWAY };
   static const gchar * const messages[] = { "", "Fixing it",
       "GON OUT BACKSON" };
-  GHashTable *location_1 = tp_asv_new (
-      "country",  G_TYPE_STRING, "United-kingdoms", NULL);
-  GHashTable *location_2 = tp_asv_new (
-      "country",  G_TYPE_STRING, "Atlantis", NULL);
-  GHashTable *location_3 = tp_asv_new (
-      "country",  G_TYPE_STRING, "Belgium", NULL);
-  GHashTable *locations[] = { location_1, location_2, location_3 };
   TpHandleRepoIface *service_repo = tp_base_connection_get_handles (
       (TpBaseConnection *) service_conn, TP_HANDLE_TYPE_CONTACT);
   TpContact *contacts[3];
   TpContactFeature features[] = { TP_CONTACT_FEATURE_ALIAS,
-      TP_CONTACT_FEATURE_AVATAR_TOKEN, TP_CONTACT_FEATURE_PRESENCE,
-      TP_CONTACT_FEATURE_LOCATION };
+      TP_CONTACT_FEATURE_AVATAR_TOKEN, TP_CONTACT_FEATURE_PRESENCE };
   guint i;
 
   g_message (G_STRFUNC);
@@ -427,8 +409,6 @@ test_upgrade (Fixture *f,
       statuses, messages);
   tp_tests_contacts_connection_change_avatar_tokens (service_conn, 3, handles,
       tokens);
-  tp_tests_contacts_connection_change_locations (service_conn, 3, handles,
-      locations);
 
   tp_connection_get_contacts_by_handle (client_conn,
       3, handles,
@@ -516,10 +496,8 @@ test_upgrade (Fixture *f,
       g_assert_cmpstr (tp_contact_get_presence_message (contacts[i]), ==,
           messages[i]);
 
-      MYASSERT (tp_contact_has_feature (contacts[i],
+      MYASSERT (!tp_contact_has_feature (contacts[i],
             TP_CONTACT_FEATURE_LOCATION), "");
-      ASSERT_SAME_LOCATION (tp_contact_get_location (contacts[i]),
-          locations[i]);
     }
 
   g_assert_cmpuint (tp_contact_get_presence_type (contacts[0]), ==,
@@ -541,9 +519,6 @@ test_upgrade (Fixture *f,
     }
 
   /* remaining cleanup */
-  g_hash_table_unref (location_1);
-  g_hash_table_unref (location_2);
-  g_hash_table_unref (location_3);
   g_main_loop_unref (result.loop);
   g_ptr_array_free (result.contacts, TRUE);
   g_assert (result.invalid == NULL);
@@ -557,7 +532,6 @@ typedef struct
   gboolean presence_type_changed;
   gboolean presence_status_changed;
   gboolean presence_msg_changed;
-  gboolean location_changed;
 } notify_ctx;
 
 static void
@@ -568,7 +542,6 @@ notify_ctx_init (notify_ctx *ctx)
   ctx->presence_type_changed = FALSE;
   ctx->presence_status_changed = FALSE;
   ctx->presence_msg_changed = FALSE;
-  ctx->location_changed = FALSE;
 }
 
 static gboolean
@@ -576,7 +549,7 @@ notify_ctx_is_fully_changed (notify_ctx *ctx)
 {
   return ctx->alias_changed && ctx->avatar_token_changed &&
     ctx->presence_type_changed && ctx->presence_status_changed &&
-    ctx->presence_msg_changed && ctx->location_changed;
+    ctx->presence_msg_changed;
 }
 
 static gboolean
@@ -584,7 +557,7 @@ notify_ctx_is_changed (notify_ctx *ctx)
 {
   return ctx->alias_changed || ctx->avatar_token_changed ||
     ctx->presence_type_changed || ctx->presence_status_changed ||
-    ctx->presence_msg_changed || ctx->location_changed;
+    ctx->presence_msg_changed;
 }
 
 static void
@@ -602,8 +575,6 @@ contact_notify_cb (TpContact *contact,
     ctx->presence_status_changed = TRUE;
   else if (!tp_strdiff (param->name, "presence-message"))
     ctx->presence_msg_changed = TRUE;
-  else if (!tp_strdiff (param->name, "location"))
-    ctx->location_changed = TRUE;
 }
 
 static void
@@ -632,24 +603,11 @@ test_features (Fixture *f,
       TP_TESTS_CONTACTS_CONNECTION_STATUS_AVAILABLE };
   static const gchar * const new_messages[] = { "At the Mad Hatter's",
       "It'll cost you" };
-  GHashTable *location_1 = tp_asv_new (
-      "country",  G_TYPE_STRING, "United-kingdoms", NULL);
-  GHashTable *location_2 = tp_asv_new (
-      "country",  G_TYPE_STRING, "Atlantis", NULL);
-  GHashTable *location_3 = tp_asv_new (
-      "country",  G_TYPE_STRING, "Belgium", NULL);
-  GHashTable *locations[] = { location_1, location_2, location_3 };
-  GHashTable *location_4 = tp_asv_new (
-      "country",  G_TYPE_STRING, "France", NULL);
-  GHashTable *location_5 = tp_asv_new (
-      "country",  G_TYPE_STRING, "Irland", NULL);
-  GHashTable *new_locations[] = { location_4, location_5 };
   TpHandleRepoIface *service_repo = tp_base_connection_get_handles (
       (TpBaseConnection *) service_conn, TP_HANDLE_TYPE_CONTACT);
   TpContact *contacts[3];
   TpContactFeature features[] = { TP_CONTACT_FEATURE_ALIAS,
-      TP_CONTACT_FEATURE_AVATAR_TOKEN, TP_CONTACT_FEATURE_PRESENCE,
-      TP_CONTACT_FEATURE_LOCATION };
+      TP_CONTACT_FEATURE_AVATAR_TOKEN, TP_CONTACT_FEATURE_PRESENCE };
   guint i;
   struct {
       TpConnection *connection;
@@ -660,7 +618,6 @@ test_features (Fixture *f,
       TpConnectionPresenceType presence_type;
       gchar *presence_status;
       gchar *presence_message;
-      GHashTable *location;
   } from_gobject;
   notify_ctx notify_ctx_alice, notify_ctx_chris;
 
@@ -675,8 +632,6 @@ test_features (Fixture *f,
       statuses, messages);
   tp_tests_contacts_connection_change_avatar_tokens (service_conn, 3, handles,
       tokens);
-  tp_tests_contacts_connection_change_locations (service_conn, 3, handles,
-      locations);
 
   tp_connection_get_contacts_by_handle (client_conn,
       3, handles,
@@ -716,10 +671,8 @@ test_features (Fixture *f,
       g_assert_cmpstr (tp_contact_get_presence_message (contacts[i]), ==,
           messages[i]);
 
-      MYASSERT (tp_contact_has_feature (contacts[i],
+      MYASSERT (!tp_contact_has_feature (contacts[i],
             TP_CONTACT_FEATURE_LOCATION), "");
-      ASSERT_SAME_LOCATION (tp_contact_get_location (contacts[i]),
-          locations[i]);
     }
 
   g_assert_cmpuint (tp_contact_get_presence_type (contacts[0]), ==,
@@ -745,7 +698,6 @@ test_features (Fixture *f,
       "presence-type", &from_gobject.presence_type,
       "presence-status", &from_gobject.presence_status,
       "presence-message", &from_gobject.presence_message,
-      "location", &from_gobject.location,
       NULL);
   MYASSERT (from_gobject.connection == client_conn, "");
   g_assert_cmpuint (from_gobject.handle, ==, handles[0]);
@@ -756,14 +708,12 @@ test_features (Fixture *f,
       TP_CONNECTION_PRESENCE_TYPE_AVAILABLE);
   g_assert_cmpstr (from_gobject.presence_status, ==, "available");
   g_assert_cmpstr (from_gobject.presence_message, ==, "");
-  ASSERT_SAME_LOCATION (from_gobject.location, locations[0]);
   g_object_unref (from_gobject.connection);
   g_free (from_gobject.identifier);
   g_free (from_gobject.alias);
   g_free (from_gobject.avatar_token);
   g_free (from_gobject.presence_status);
   g_free (from_gobject.presence_message);
-  g_hash_table_unref (from_gobject.location);
 
   notify_ctx_init (&notify_ctx_alice);
   g_signal_connect (contacts[0], "notify",
@@ -780,8 +730,6 @@ test_features (Fixture *f,
       new_statuses, new_messages);
   tp_tests_contacts_connection_change_avatar_tokens (service_conn, 2, handles,
       new_tokens);
-  tp_tests_contacts_connection_change_locations (service_conn, 2, handles,
-      new_locations);
   tp_tests_proxy_run_until_dbus_queue_processed (client_conn);
 
   g_assert (notify_ctx_is_fully_changed (&notify_ctx_alice));
@@ -808,10 +756,8 @@ test_features (Fixture *f,
       g_assert_cmpstr (tp_contact_get_presence_message (contacts[i]), ==,
           new_messages[i]);
 
-      MYASSERT (tp_contact_has_feature (contacts[i],
+      MYASSERT (!tp_contact_has_feature (contacts[i],
             TP_CONTACT_FEATURE_LOCATION), "");
-      ASSERT_SAME_LOCATION (tp_contact_get_location (contacts[i]),
-          new_locations[i]);
     }
 
   g_assert_cmpuint (tp_contact_get_presence_type (contacts[0]), ==,
@@ -835,11 +781,6 @@ test_features (Fixture *f,
   g_array_free (result.invalid, TRUE);
   g_ptr_array_free (result.contacts, TRUE);
   g_assert (result.error == NULL);
-  g_hash_table_unref (location_1);
-  g_hash_table_unref (location_2);
-  g_hash_table_unref (location_3);
-  g_hash_table_unref (location_4);
-  g_hash_table_unref (location_5);
 }
 
 static void
@@ -1299,11 +1240,7 @@ int
 main (int argc,
       char **argv)
 {
-  g_type_init ();
-  tp_debug_set_flags ("all");
-  tp_tests_abort_after (10);
-  g_set_prgname ("contacts-slow-path");
-  g_test_init (&argc, &argv, NULL);
+  tp_tests_init (&argc, &argv);
   g_test_bug_base ("http://bugs.freedesktop.org/show_bug.cgi?id=");
 
   g_test_add ("/contacts-slow-path/by-handle", Fixture, NULL, setup,
